Struct EuropePmcCitation
pub struct EuropePmcCitation {
pub id: Option<String>,
pub source: Option<String>,
pub citation_type: Option<String>,
pub title: Option<String>,
pub author_string: Option<String>,
pub journal_abbreviation: Option<String>,
pub pub_year: Option<String>,
pub volume: Option<String>,
pub issue: Option<String>,
pub page_info: Option<String>,
pub cited_by_count: Option<String>,
pub extra: Map<String, Value>,
}Expand description
A citing article from the Europe PMC citations endpoint.
Fields
id: Option<String>Identifier of the citing record within its source database.
source: Option<String>Source database code of the citing record.
citation_type: Option<String>Citation type (e.g. "JOURNAL ARTICLE").
title: Option<String>Title of the citing article.
Comma-separated author list of the citing article.
journal_abbreviation: Option<String>Abbreviated journal name.
pub_year: Option<String>Publication year.
volume: Option<String>Journal volume.
issue: Option<String>Journal issue.
page_info: Option<String>Page range / location.
cited_by_count: Option<String>Number of times the citing article has itself been cited.
extra: Map<String, Value>Any additional fields not modelled above.