OaSubsetInfo

Struct OaSubsetInfo 

pub struct OaSubsetInfo {
    pub pmcid: String,
    pub is_oa_subset: bool,
    pub citation: Option<String>,
    pub license: Option<String>,
    pub retracted: bool,
    pub download_link: Option<String>,
    pub download_format: Option<String>,
    pub updated: Option<String>,
    pub error_code: Option<String>,
    pub error_message: Option<String>,
}
Information about OA (Open Access) subset availability for a PMC article

The OA subset contains articles with programmatic access to full-text XML. Not all PMC articles are in the OA subset - some publishers restrict programmatic access even though the article may be viewable on the PMC website.

Fields

pmcid: String

PMC ID (e.g., “PMC7906746”)

is_oa_subset: bool

Whether the article is in the OA subset

citation: Option<String>

Citation string (if available)

license: Option<String>

License type (if available)

retracted: bool

Whether the article is retracted

download_link: Option<String>

Download link for tar.gz package (if available)

download_format: Option<String>

Format of the download (e.g., “tgz”, “pdf”)

updated: Option<String>

Last updated timestamp for the download

error_code: Option<String>

Error code if not in OA subset

error_message: Option<String>

Error message if not in OA subset

Implementations



impl OaSubsetInfo

pub fn available(pmcid: String) -> OaSubsetInfo

Create a new OaSubsetInfo for an article in the OA subset

pub fn not_available( pmcid: String, error_code: String, error_message: String, ) -> OaSubsetInfo

Create a new OaSubsetInfo for an article NOT in the OA subset