Struct HistorySession
pub struct HistorySession {
pub webenv: String,
pub query_key: String,
}Expand description
History server session information for paginated fetching
This represents a session on NCBI’s history server that can be used to efficiently fetch large result sets in batches without re-running the search query.
Note
WebEnv sessions typically expire after 1 hour of inactivity.
Fields
webenv: StringWebEnv session identifier
query_key: StringQuery key within the session